export interface ReduxAction {
    type: any;
}
export interface ErrorAction extends ReduxAction {
    payload: any;
    error: boolean;
}
export interface Action<TPayload> extends ReduxAction {
    payload: TPayload;
}
export interface CreateAction<TPayload> extends Action<TPayload> {
    (payload?: TPayload): Action<TPayload>;
    matches(action: ReduxAction): action is Action<TPayload>;
    type: string;
}
export declare const createAction: <TPayload>(type: string) => CreateAction<TPayload>;
export declare type HttpMethod = 'GET' | 'HEAD' | 'PUT' | 'POST' | 'PATCH' | 'DELETE' | 'OPTIONS';
export interface ICallApiOptions {
    endpoint: string;
    method: HttpMethod;
    types: string[];
    body?: any;
    credentials?: 'omit' | 'same-origin' | 'include';
    headers?: {
        [propName: string]: string;
    };
}
export interface ApiAction<TPayload, TResponse> {
    [propName: string]: ICallApiOptions;
}
export interface IApiActionOptions {
    CALL_API: any;
    endpoint: string;
    method: HttpMethod;
    credentials?: 'omit' | 'same-origin' | 'include';
    headers?: {
        [propName: string]: string;
    };
}
export interface CreateApiAsyncAction<TPayload, TResponse> {
    (payload?: TPayload): ApiAction<TPayload, TResponse>;
    matches(action: Action<any>): action is Action<any>;
    matchesPending(action: Action<TPayload>): action is Action<TPayload>;
    matchesSuccess(action: Action<TResponse>): action is Action<TResponse>;
    matchesFailure(action: Action<any>): action is ErrorAction;
    type: string;
}
export declare type CreateApiActionOptions<TPayload> = IApiActionOptions | ((payload: TPayload) => IApiActionOptions);
export declare const createApiAction: <TPayload, TResponse>(type: string, options: CreateApiActionOptions<TPayload>, addOn?: any) => CreateApiAsyncAction<TPayload, TResponse>;
